Python: module src.inputgen

src.inputgen (21 April 2007) | index /Users/d3y382/workspaces/apbs-pdb2pqr/pdb2pqr/src/inputgen.py

`inputgen class
Create an APBS input file using psize data
Written by Todd Dolinsky based on original sed script by Nathan Baker
----------------------------
PDB2PQR -- An automated pipeline for the setup, execution, and analysis of
Poisson-Boltzmann electrostatics calculations
Copyright (c) 2002-2011, Jens Erik Nielsen, University College Dublin;
Nathan A. Baker, Battelle Memorial Institute, Developed at the Pacific
Northwest National Laboratory, operated by Battelle Memorial Institute,
Pacific Northwest Division for the U.S. Department Energy.;
Paul Czodrowski & Gerhard Klebe, University of Marburg.
All rights reserved.
Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:
* Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.
* Neither the names of University College Dublin, Battelle Memorial Institute,
Pacific Northwest National Laboratory, US Department of Energy, or University
of Marburg nor the names of its contributors may be used to endorse or promote
products derived from this software without specific prior written permission.
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
OF THE POSSIBILITY OF SUCH DAMAGE.
----------------------------`

Modules
`` |  |
os pickle | src.psize string | sys src.utilities |

Classes
`` |  | Elec Input
class Elec
`` | `An object for the ELEC section of an APBS input file`
| Methods defined here: __init__(self, pqrpath, size, method, asyncflag, istrng=0, potdx=False) `Initialize the variables that can be set in this object Users can modify any of these variables (that's why they're here!)` __str__(self) `Return the elec statement as a string. Check the method to see which keywords to use.`
class Input
`` | `The input class. Each input object is one APBS input file.`
| Methods defined here: __init__(self, pqrpath, size, method, asyncflag, istrng=0, potdx=False) `Initialize the input file class. Each input file contains a PQR name, a list of elec objects, and a list of strings containing print statements. For starters assume two ELEC statements are needed, one for the inhomgenous and the other for the homogenous dielectric calculations. Users can edit the elec statements and the print statements. This assumes you have already run psize, either by size.runPsize(/path/to/pqr) or size.parseString(string) size.setAll() Parameters pqrpath: The path to the PQR file (string) size: The Psize object (psize) method: The method (para, auto, manual, async) to use asyncflag: 1 if async is desired, 0 otherwise` __str__(self) `Return the text of the input file` dumpPickle(self) `Make a Python pickle associated with the APBS input parameters` printInputFiles(self) `Make the input file(s) associated with this object`

Functions
`` |  | main() splitInput(filename) `Split the parallel input file into multiple async file names Parameters filename: The path to the original parallel input file (string)` usage() `Display the usage information for this script`

Data
`` |  | __author__ = 'Todd Dolinsky, Nathan Baker, Yong Huang' __date__ = '21 April 2007'

Author
`` |  | Todd Dolinsky, Nathan Baker, Yong Huang